@@ -113,6 +113,9 @@ class Namespace:
             value = ".".join([str(v) for v in value])
         if strip:
             value = value.rstrip(".*")
+            # namespace was all wildcards
+            if value == "":
+                value = "*"
         self.value = value
         self.keys = [k for k in self]
         self.length = len(self.keys)
@@ -379,6 +382,7 @@ class PermissionSet:
             branch = idx
             parent_p = None
             for k in p.namespace.keys:
+
                 if not k in branch:
                     branch[k] = {"__": parent_p}
                     branch[k].update(__implicit=True)
@@ -489,9 +493,9 @@ class PermissionSet:
                 )
 
         # if debug:
-        #    print("")
-        #    print("KEYS (inner)", keys[:i], "pos", i, "flags", flags, "length", l, "expl", explicit, "impl", implicit)
-        #    print("key", key, "flag", key_flag, "implicit", key_implicit, "pos", key_pos, "wc flag", wc_flag, "wc implicit", wc_implicit, "wc pos",  wc_pos)
+        #   print("")
+        #   print("KEYS (inner)", keys[:i], "pos", i, "flags", flags, "length", l, "expl", explicit, "impl", implicit)
+        #   print("key", key, "flag", key_flag, "implicit", key_implicit, "pos", key_pos, "wc flag", wc_flag, "wc implicit", wc_implicit, "wc pos",  wc_pos)
 
         # explicit namespace match required but not found
 
@@ -808,8 +812,7 @@ class Applicator:
                 else:
                     return None
 
-            if not wc:
-                status = ramap.get("__", status)
+            status = ramap.get("__", status)
 
             handler = None
             key_handler = None
